dwca package
============

Package for reading `Darwin Core Archive (DwCA) <https://dwc.tdwg.org/text/>`_ files.

Darwin Core Base Class
----------------------

.. automodule:: dwca.base.darwincore
   :members:
   :undoc-members:
   :show-inheritance:

Darwin Core Archive Class
-------------------------

.. automodule:: dwca.base.darwincore_archive
   :members:
   :undoc-members:
   :show-inheritance:

Simple Darwin Core Class
------------------------

.. automodule:: dwca.base.simple_darwincore
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 3

   dwca.classes
   dwca.terms
